# Libraries used in analysis
library(MASS)

# Load the data into the environment
data(road)

#################
# Start analysis#
#################

#
# Part A.
#
# Briefly explain why when conducting a principal component analysis
# analysts will scale the features available to have unit variance.

# When variables are measured in different units, this will affect the 
# loadings they generate. Changing to different units will affect the variance
# and therefore the composition of the principal components. Scaling the
# variables will ensure that arbitrary selection of units does not impact the 
# resultant principal components.



#
# Part B.
#
# Create a principal component analysis model for this data making
# sure that each feature has mean zero and variance 1.
# Display a summary of the fitted model and explain to a
# non-technical audience what the first two principal components
# reveal about the road data.

pcm <- prcomp( ~ deaths + drivers + popden + rural + temp + fuel,
               data = road,
               center = TRUE,
               scale. = TRUE)
summary(pcm)

# The first principal component shows the direction in feature
# space that the data has the most variation.
# The second principal component is constrained to be orthogonal 
# to the first and has a direction along which the data also
# varies the most.
#
# From the summary we can see that the first two components
# capture about 70% of the variation in the data.


#
# Part C.
#
# Create a biplot of the model you fitted in Part B and interpret the
# information presented by this plot.

biplot(pcm)

# From the biplot we can see that the variables rural and fuel are
# highly correlated. Also the variables drivers and deaths are 
# highly correlated. These two pairs of variables have also large
# positive loadings for the first principal component.

# Temperature has a small first component loading, but a large
# second component loading suggesting that this direction we 
# will also see differences in the states.

# Similarly, population density has a large second principal
# component.

# Observe that most of the states with negative second principal
# component loadings are in the south: Florida, Louisiana, Arizona,
# Mississippi, Alabama.  States with large positive second component
# are Minnesota, Iowa, Montana, Michigan, and Illinois whose January
# temperatures are much lower than the other states mentioned.

# California and DC stand out as outliers. DC is in the direction
# of population density and it is the "state" that has the highest 
# density. California has large loadings in both directions.
#

#
# Part D.
#
# Display the loadings from the model and verify that the square of the
# loading are constrained to sum to 1. Explain how the loadings are used
# to create the biplot shown in Part C.

pcm
apply(pcm$rotation, 2, function(x) sum(x^2))

# Each column of the 6 x 6 rotation matrix corresponds to the loadings
# to be applied to the columns of our data. Using the first column, that
# is the loadings for the first principal component, we would compute the
# dot product of this vector with each row of our data.  This gives us 
# the coordinate, for each state, for the first principal component.
# Similarly, calculating the dot product of the second column with each 
# row of data will give us the coordinate for the second principal
# component.  The two points are used to plot the state name on the
# biplot using the scales on the bottom and left of the display.

# The red arrows in the biplot are the points with coordinates from 
# the first two columns of the loadings matrix. 

#
# Part E.
#
# Based on the analysis so far, recommend the number of principal
# components you would use to adequately summarize the data.

# From the summary in Part B we know that the first principal
# component explains about 50% of the variation in the data.
# The first three components explain about 84% of the variation.
# Depending on the goals of the analysis, we might need 3 or 4
# principal components to adequately summarize the data.
